@@ -17,48 +17,48 @@
 #include "objects/Edge.hpp"
 #include "networks/Network.hpp"
 #include "community/VertexLayerCommunity.hpp"
-#include "networks/AttributedHomogeneousMultilayerNetwork.hpp"
+#include "networks/MultilayerNetwork.hpp"
 #include "r_functions.h"
 
 std::vector<uu::net::Network*>
 resolve_layers(
-    const uu::net::AttributedHomogeneousMultilayerNetwork* mnet,
+    const uu::net::MultilayerNetwork* mnet,
     const Rcpp::CharacterVector& names
 );
 
 std::unordered_set<uu::net::Network*>
 resolve_layers_unordered(
-    const uu::net::AttributedHomogeneousMultilayerNetwork* mnet,
+    const uu::net::MultilayerNetwork* mnet,
     const Rcpp::CharacterVector& names
 );
 
 std::unordered_set<const uu::net::Network*>
 resolve_const_layers_unordered(
-    const uu::net::AttributedHomogeneousMultilayerNetwork* mnet,
+    const uu::net::MultilayerNetwork* mnet,
     const Rcpp::CharacterVector& names
 );
 
 std::vector<const uu::net::Vertex*>
 resolve_actors(
-    const uu::net::AttributedHomogeneousMultilayerNetwork* mnet,
+    const uu::net::MultilayerNetwork* mnet,
     const Rcpp::CharacterVector& names
 );
 
 std::unordered_set<const uu::net::Vertex*>
 resolve_actors_unordered(
-    const uu::net::AttributedHomogeneousMultilayerNetwork* mnet,
+    const uu::net::MultilayerNetwork* mnet,
     const Rcpp::CharacterVector& names
 );
 
 std::vector<std::pair<const uu::net::Vertex*, uu::net::Network*>>
         resolve_vertices(
-            const uu::net::AttributedHomogeneousMultilayerNetwork* mnet,
+            const uu::net::MultilayerNetwork* mnet,
             const Rcpp::DataFrame& vertex_matrix
         );
 
 std::vector<std::tuple<const uu::net::Vertex*, uu::net::Network*, const uu::net::Vertex*, uu::net::Network*>>
         resolve_edges(
-            const uu::net::AttributedHomogeneousMultilayerNetwork* mnet,
+            const uu::net::MultilayerNetwork* mnet,
             const Rcpp::DataFrame& edge_matrix
         );
 
@@ -76,7 +76,7 @@ to_dataframe(
 std::unique_ptr<uu::net::CommunityStructure<uu::net::VertexLayerCommunity<const uu::net::Network>>>
 to_communities(
                const DataFrame& com,
-               const uu::net::AttributedHomogeneousMultilayerNetwork* mnet
+               const uu::net::MultilayerNetwork* mnet
                );
 
 #endif
